#from __future__ import annotations
USING_STRINGS = True

# dataclass_module_2.py and dataclass_module_2_str.py are identical
# except only the latter uses string annotations.

from dataclasses import dataclass, InitVar
from typing import ClassVar

T_CV2 = ClassVar[int]
T_CV3 = ClassVar

T_IV2 = InitVar[int]
T_IV3 = InitVar

@dataclass
class CV:
    T_CV4 = "ClassVar"
    cv0: "ClassVar[int]" = 20
    cv1: "ClassVar" = 30
    cv2: "T_CV2"
    cv3: "T_CV3"
    not_cv4: "T_CV4"  # When using string annotations, this field is not recognized as a ClassVar.

@dataclass
class IV:
    T_IV4 = "InitVar"
    iv0: "InitVar[int]"
    iv1: "InitVar"
    iv2: "T_IV2"
    iv3: "T_IV3"
    not_iv4: "T_IV4"  # When using string annotations, this field is not recognized as an InitVar.



import dataclasses

def add_slots(cls):
    # Need to create a new class, since we can't set __slots__
    #  after a class has been created.

    # Make sure __slots__ isn't already set.
    if '__slots__' in cls.__dict__:
        raise TypeError(f'{cls.__name__} already specifies __slots__')

    # Create a new dict for our new class.
    cls_dict = dict(cls.__dict__)
    field_names = tuple(f.name for f in dataclasses.fields(cls))
    cls_dict['__slots__'] = field_names
    for field_name in field_names:
        # Remove our attributes, if present. They'll still be
        #  available in _MARKER.
        cls_dict.pop(field_name, None)
    # Remove __dict__ itself.
    cls_dict.pop('__dict__', None)
    # And finally create the class.
    qualname = getattr(cls, '__qualname__', None)
    cls = type(cls)(cls.__name__, cls.__bases__, cls_dict)
    if qualname is not None:
        cls.__qualname__ = qualname
    return cls





from setuptools import setup

with open("README.rst") as readme:
    README = readme.read()

setup(
    name="dataclasses",
    version="0.8",
    description="A backport of the dataclasses module for Python 3.6",
    long_description=README,
    url="https://github.com/ericvsmith/dataclasses",
    author="Eric V. Smith",
    author_email="eric@python.org",
    license="Apache",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3.6",
    ],
    py_modules=["dataclasses"],
    python_requires=">=3.6, <3.7",
)
